dotenv

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 9, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package dotenv provides a simple helper to write profiles to dotenv files.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DotEnv

type DotEnv struct {
	Profile string
	Path    file.File
}

DotEnv represents a dotenv file for a specific profile.

func (DotEnv) WriteFrom

func (d DotEnv) WriteFrom(profiles *profile.Profiles) error

WriteFrom writes the environment variables for the profile to the dotenv file.

Jump to