Documentation
¶
Overview ¶
Package envprof loads and unmarshals environment profile configurations from various file formats. It supports YAML, TOML and JSON formats for defining environment profiles.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type EnvProf ¶
type EnvProf struct {
// contains filtered or unexported fields
}
EnvProf represents an environment profile file and its loaded content.
func (*EnvProf) GetOrDefault ¶
GetOrDefault returns the profile name if it exists, or the default profile if none is specified.
Click to show internal directories.
Click to hide internal directories.