terminal

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 21, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package terminal provides functionality to spawn a terminal with a specific environment.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Current

func Current() string

Current tries to determine the current terminal being used.

func Spawn

func Spawn(shell string, env []string) error

Spawn launches a new shell with the specified environment variables.

Types

This section is empty.

Jump to