Documentation
¶
Overview ¶
Package cli implements the command-line interface for envprof.
Index ¶
- func Exec(options *Options) *cobra.Command
- func Execute(version string) error
- func Export(options *Options) *cobra.Command
- func List(options *Options) *cobra.Command
- func Profiles(options *Options) *cobra.Command
- func Shell(options *Options) *cobra.Command
- func UnknownSubcommandAction(cmd *cobra.Command, args []string) error
- func Write(options *Options) *cobra.Command
- type Options
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Exec ¶ added in v0.0.6
Exec returns the cobra command for executing a command with the active environment.
func Shell ¶ added in v0.0.1
Shell returns the cobra command for entering a scoped shell with the active environment.
func UnknownSubcommandAction ¶ added in v0.0.8
UnknownSubcommandAction handles unknown cobra subcommands. Implements cobra.Command.RunE to provide helpful error messages and suggestions when an unknown subcommand is used. Required when TraverseChildren is true, as this disables cobra's built-in suggestion system. See: - https://github.com/spf13/cobra/issues/981 - https://github.com/containerd/nerdctl/blob/242e6fc6e861b61b878bd7df8bf25e95674c036d/cmd/nerdctl/main.go#L401-L418