cli

package
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 15, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package cli implements the command-line interface for envprof.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Exec added in v0.0.6

func Exec(envprof *[]string) *cobra.Command

Exec returns the cobra command for executing a command with the active environment.

func Execute

func Execute(version string) error

Execute runs the root command for the envprof CLI application.

func Export

func Export(envprof *[]string) *cobra.Command

Export defines the command for exporting a profile's variables.

func List

func List(envprof *[]string) *cobra.Command

List returns the cobra command for listing profiles and their variables.

func Shell added in v0.0.1

func Shell(envprof *[]string) *cobra.Command

Shell returns the cobra command for entering a scoped shell with the active environment.

func Write added in v0.0.6

func Write(envprof *[]string) *cobra.Command

Write defines the command for writing profile variables to one or multiple dotenv files.

Types

This section is empty.

Jump to