cli

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 9, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package cli implements the command-line interface for envprof.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Env added in v0.0.4

func Env(envprof *[]string) *cobra.Command

Env defines the command for exporting profile variables to one or multiple dotenv files.

func Execute

func Execute(version string) error

Execute runs the root command for the envprof CLI application.

func Export

func Export(envprof *[]string) *cobra.Command

Export defines the command for exporting a profile's variables. It emits '<prefix> KEY=VAL' lines or writes them out as a dotenv file. By default, 'prefix' is set to "export".

func List

func List(envprof *[]string) *cobra.Command

List returns the cobra command for listing profiles and their variables.

func Shell added in v0.0.1

func Shell(envprof *[]string) *cobra.Command

Shell returns the cobra command for entering a scoped shell with the environment active.

Types

This section is empty.

Jump to