Documentation
¶
Overview ¶
Package cli implements the command-line interface for envprof.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Env ¶ added in v0.0.4
Env defines the command for exporting profile variables to one or multiple dotenv files.
func Export ¶
Export defines the command for exporting a profile's variables. It emits '<prefix> KEY=VAL' lines or writes them out as a dotenv file. By default, 'prefix' is set to "export".
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.