cli

package
v0.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package cli implements the command-line interface for envprof.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Convert

func Convert(flags *Flags) *cobra.Command

Convert returns the cobra command for converting the config format.

func Execute

func Execute() error

Execute runs the root command for the envprof CLI application.

func Export

func Export(flags *Flags) *cobra.Command

Export returns the cobra command for exporting a profile's variables.

func Import

func Import(flags *Flags) *cobra.Command

Import returns the cobra command for importing a dotenv file into a profile.

func List

func List(flags *Flags) *cobra.Command

List returns the cobra command for listing profiles and their variables.

Types

type Flags

type Flags struct {
	// File is the config file to use, in order of preference.
	File []string
	// Verbose enables verbose output.
	Verbose bool
}

Flags holds the command-line flags for the envprof CLI application.

Jump to