Documentation
¶
Overview ¶
Package profiles manages collections of environment profiles and their relationships. It handles profile resolution, validation, and environment generation with inheritance support.
Index ¶
- Variables
- type Profiles
- func (p Profiles) Default() string
- func (p Profiles) Defaults() (defaults []string)
- func (p Profiles) Environment(name string, steps step.Steps) (environment.Environment, error)
- func (p Profiles) Environments() (environments []environment.Environment, err error)
- func (p Profiles) Exists(name string) bool
- func (p Profiles) Get(name string) (profile.Profile, error)
- func (p Profiles) Names() []string
- func (p Profiles) Plan(root string, overlays ...string) (step.Steps, error)
- func (p Profiles) Validate() error
Constants ¶
This section is empty.
Variables ¶
var ErrValidation = errors.New("validation error")
ErrValidation is returned when profiles validation fails.
Functions ¶
This section is empty.
Types ¶
type Profiles ¶
Profiles is a map of profile names to their metadata.
func (Profiles) Environment ¶
func (p Profiles) Environment(name string, steps step.Steps) (environment.Environment, error)
Environment returns a fully resolved environment for a specific profile.
func (Profiles) Environments ¶
func (p Profiles) Environments() (environments []environment.Environment, err error)
Environments returns a fully resolved list of environments for all profiles.
func (Profiles) Get ¶
Get retrieves a profile by name. Returns an error for empty or non-existing profile names.
Click to show internal directories.
Click to hide internal directories.